/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * \file   src/cpu/cpu_generic.c
 * Generic CPU detection.
 *
 * Includes functions for detecting and parsing Linux/x86 cpuinfo.
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "src/uhinv.h"

#include "cpu_generic.h"
#include "cpu_linux.h"

/**
 * Get cpu information.
 *
 * Needs to know what arch we're on so that we can decide how to detect and
 * parse CPU information.
 *
 * \param cpu_info    Results go here
 * \param arch        What arch are we on?
 */
    int
get_cpu_info(cpu_info, arch)
    cpu_info_T **cpu_info;
    char *arch;
{
    int success = 0;

    if (!success)
        success = get_cpu_linux_info(cpu_info, arch);

    if (!success)
        (*cpu_info)->count = 0;

    return success;
}

/* vim: set tw=80 sw=4 et : */
