/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * \file   src/cpu/cpu_linux_arm.c
 * Linux/ARM CPU detection.
 *
 * Includes functions for detecting and parsing Linux/ARM cpuinfo.
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "src/uhinv.h"
#include "src/util/util.h"

#include "cpu_generic.h"
#include "cpu_linux.h"

/**
 * Get cpuinfo from a Linux/ARM cpuinfo file.
 *
 * Parses a /proc/cpuinfo file (must be already fopen()ed) and places the
 * results into cpu_info.
 *
 * \param cpu_info     Parsed info goes here
 * \param proccpuinfo  Filehandle (pre-fopen()ed) from which to read
 */
    int
get_cpu_linux_arm_info(cpu_info, proccpuinfo)
    cpu_info_T **cpu_info;
    FILE *proccpuinfo;
{
    char keybuf[KEYBUF_SIZE];
    char valuebuf[VALUEBUF_SIZE];

    /* The guy with the ARM says he doesn't know of any SMP ARM kit. If you know
     * different, send patches please :) */
    (*cpu_info)->count = 1;
    *cpu_info = realloc(*cpu_info,
            sizeof(cpu_info_T) +
            (*cpu_info)->count * sizeof(one_cpu_info_T));
    one_cpu_info_T *curr_cpu = &(*cpu_info)->processors[(*cpu_info)->count - 1];

    strncpynull(curr_cpu->vendor,        "", CPU_INFO_BUFSIZE);
    strncpynull(curr_cpu->model_name,    "", CPU_INFO_BUFSIZE);
    strncpynull(curr_cpu->model_speed,   "", CPU_INFO_BUFSIZE);

    while (!feof(proccpuinfo))
    {
        if (get_proc_cpuinfo_entry(proccpuinfo, keybuf, valuebuf))
        {
            if (0 == strcmp(keybuf, "Processor"))
            {
                /* look for StrongARM-110 and parse out the number */
                if (0 == strncmp(valuebuf, "StrongARM-", 10))
                {
                    char *speed_start = &valuebuf[0] + 10;
                    char *speed_end   = speed_start;
                    while ((*speed_end >= '0') && (*speed_end <= '9'))
                        ++speed_end;
                    if (speed_end != speed_start)
                    {
                        *(speed_start - 1) = '\0';
                        *speed_end = '\0';
                        strncpynull(curr_cpu->model_speed,
                                speed_start, CPU_INFO_BUFSIZE);
                        snprintf((char *) curr_cpu->model_name, (size_t) CPU_INFO_BUFSIZE,
                                "%s %s", valuebuf, (char *)(speed_end + 1));
                    }
                    else
                        strncpynull(curr_cpu->model_name,
                                valuebuf, CPU_INFO_BUFSIZE);
                }
                else
                    strncpynull(curr_cpu->model_name,
                            valuebuf, CPU_INFO_BUFSIZE);
            }
            else if (0 == strcmp(keybuf, "Hardware"))
            {
                strncpynull(curr_cpu->vendor, valuebuf, CPU_INFO_BUFSIZE);
            }
        }
    }

    return 1;
}

/* vim: set tw=80 sw=4 et : */
