/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * \file   src/cpu/cpu_linux_parisc.c
 * Linux/PARISC CPU detection.
 *
 * Includes functions for detecting and parsing Linux/PARISC cpuinfo.
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "src/uhinv.h"
#include "src/util/util.h"

#include "cpu_generic.h"
#include "cpu_linux.h"

/**
 * Get cpuinfo from a Linux/PARISC cpuinfo file.
 *
 * Parses a /proc/cpuinfo file (must be already fopen()ed) and places the
 * results into cpu_info.
 *
 * \param cpu_info     Parsed info goes here
 * \param proccpuinfo  Filehandle (pre-fopen()ed) from which to read
 */
    int
get_cpu_linux_parisc_info(cpu_info, proccpuinfo)
    cpu_info_T **cpu_info;
    FILE *proccpuinfo;
{
    char keybuf[KEYBUF_SIZE];
    char valuebuf[VALUEBUF_SIZE];
    one_cpu_info_T dummy_cpu;

    (*cpu_info)->count = 0;

    one_cpu_info_T *curr_cpu = &dummy_cpu;

    while (!feof(proccpuinfo))
    {
        if (get_proc_cpuinfo_entry(proccpuinfo, keybuf, valuebuf))
        {
            if (0 == strcmp(keybuf, "processor"))
            {
                (*cpu_info)->count++;
                *cpu_info = realloc(*cpu_info,
                        sizeof(cpu_info_T) +
                        (*cpu_info)->count * sizeof(one_cpu_info_T));
                curr_cpu = &(*cpu_info)->processors[(*cpu_info)->count - 1];

                strncpynull(curr_cpu->vendor,        "HP",  CPU_INFO_BUFSIZE);
                strncpynull(curr_cpu->model_name,    "",    CPU_INFO_BUFSIZE);
                strncpynull(curr_cpu->model_speed,   "",    CPU_INFO_BUFSIZE);
            }
            else if (0 == strcmp(keybuf, "cpu"))
            {
                strncpynull(curr_cpu->model_name,
                        valuebuf, CPU_INFO_BUFSIZE);
            }
            else if (0 == strcmp(keybuf, "cpu MHz"))
            {
                char *dot_p;
                if ((dot_p = strchr(valuebuf, '.')))
                    *dot_p = '\0';
                strncpynull(curr_cpu->model_speed, valuebuf, CPU_INFO_BUFSIZE);
            }
        }
    }

    return 1;
}

/* vim: set tw=80 sw=4 et : */
