/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 325, Boston, MA  02111-1257  USA
 */

/**
 * \file   src/display_uhinv_text.c
 * Display functions: text format.
 *
 * Implements various display_ functions for when --format=text. The output from
 * these functions is straight machine-parsable plaintext with no complex
 * additional formatting.
 */

#include <stdlib.h>
#include <stdio.h>

#include "src/uhinv.h"

#include "src/os/os_generic.h"
#include "src/cpu/cpu_generic.h"
#include "src/mem/mem_generic.h"

/**
 * Display a section header with title 'title' indented 'indent' levels.
 *
 * \param indent   Indent level
 * \param title    Title to display
 */
    void
display_section_header_text(indent, title)
    unsigned int indent;
    char *title;
{
    int i;
    for (i = 0 ; i < (2 * indent) ; ++i)
        printf(" ");
    printf("%s\n", title);
}

/**
 * Display a compact information string indented 'indent' levels.
 *
 * The 'key' is always displayed ; the values are displayed with a space after
 * them if they are not empty. A single blank value does not prevent subsequent
 * values from being displayed.
 *
 * \param indent    Indent level
 * \param key       The key
 * \param value1    First value to display (can be an empty string)
 * \param value2    Second value to display (can be an empty string)
 * \param value3    Third value to display (can be an empty string)
 */
    void
display_compact_str_text(indent, key, value1, value2, value3)
    unsigned int indent;
    char *key;
    char *value1;
    char *value2;
    char *value3;
{
    int i;
    for (i = 0 ; i < (2 * indent) ; ++i)
        printf(" ");
    printf("%s ", key);
    if (*value1)
        printf("%s ", value1);
    if (*value2)
        printf("%s ", value2);
    if (*value3)
        printf("%s", value3);
    printf("\n");
}

/**
 * Display a key/value pair indented 'indent' levels.
 *
 * \param indent    Indent level
 * \param key       The key to be displayed
 * \param value     The value to be displayed
 */
    void
display_kvpair_str_text(indent, key, value)
    unsigned int indent;
    char *key;
    char *value;
{
    int i;
    for (i = 0 ; i < (2 * indent) ; ++i)
        printf(" ");
    printf("%-20.20s", key);
    for (i = 6 - (2 * indent) ; i >= 0 ; --i)
        printf(" ");
    printf("%s\n", value);
}

/* vim: set tw=80 sw=4 et : */
