/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * \file   src/os/os_generic.c
 * Operating system information.
 *
 * Gets operating system information. Delegates to various other functions for
 * actual detection.
 */


#include "config.h"

#include <string.h>
#include "os_generic.h"
#include "src/util/util.h"

#if defined(HAVE_UNISTD_H)
# include <unistd.h>
# if defined(HAVE_UNAME)
#  include "os_unix.h"
#  include <sys/utsname.h>
# endif
#endif

/**
 * Gets operating system information.
 *
 * \param osinfo     Results go here
 */
    void
get_operating_system_info(osinfo)
    operating_system_info_T *osinfo;
{
    strncpynull(osinfo->name,     "Unknown", OPERATING_SYSTEM_INFO_BUFSIZE);
    strncpynull(osinfo->release,  "Unknown", OPERATING_SYSTEM_INFO_BUFSIZE);
    strncpynull(osinfo->version,  "Unknown", OPERATING_SYSTEM_INFO_BUFSIZE);
    strncpynull(osinfo->machine,  "Unknown", OPERATING_SYSTEM_INFO_BUFSIZE);
    strncpynull(osinfo->hostname, "Unknown", OPERATING_SYSTEM_INFO_BUFSIZE);

#if defined(HAVE_UNISTD_H) && defined(HAVE_UNAME)
    get_unix_operating_system_info(osinfo);
#endif

#if defined(HAVE_UNISTD_H) && defined(HAVE_GETHOSTNAME)
    gethostname(osinfo->hostname, OPERATING_SYSTEM_INFO_BUFSIZE);
    osinfo->hostname[OPERATING_SYSTEM_INFO_BUFSIZE - 1] = '\0';
#endif
}

/* vim: set tw=80 sw=4 et : */
