/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


/**
 * \file   src/os/os_unix.c
 * Unix information detection.
 *
 * Gets version information about a UNIX-like operating system.
 */

#include "config.h"

#if defined(HAVE_UNISTD_H) && defined(HAVE_UNAME)

#include <sys/utsname.h>
#include <string.h>
#include <stdio.h>

#include "src/uhinv.h"
#include "src/util/util.h"

#include "os_generic.h"
#include "os_unix.h"

/**
 * Gets operating system information using uname().
 *
 * \param osinfo    Information goes here.
 */
    void
get_unix_operating_system_info(osinfo)
    operating_system_info_T *osinfo;
{
    struct utsname utsname_result;
    uname(&utsname_result);

    strncpynull(osinfo->name, utsname_result.sysname,
            OPERATING_SYSTEM_INFO_BUFSIZE - 1);
    *(osinfo->name + OPERATING_SYSTEM_INFO_BUFSIZE - 1) = '\0';

    strncpynull(osinfo->release, utsname_result.release,
            OPERATING_SYSTEM_INFO_BUFSIZE - 1);
    *(osinfo->release + OPERATING_SYSTEM_INFO_BUFSIZE - 1) = '\0';

    strncpynull(osinfo->version, utsname_result.version,
            OPERATING_SYSTEM_INFO_BUFSIZE - 1);
    *(osinfo->version + OPERATING_SYSTEM_INFO_BUFSIZE - 1) = '\0';

    strncpynull(osinfo->machine, utsname_result.machine,
            OPERATING_SYSTEM_INFO_BUFSIZE - 1);
    *(osinfo->machine + OPERATING_SYSTEM_INFO_BUFSIZE - 1) = '\0';
}

#endif

/* vim: set tw=80 sw=4 et : */
