/*
 * uhinv (Universal Hardware Inventory)
 * src/uhinv.h
 * Main application headers
 *
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 325, Boston, MA  02111-1257  USA
 */

#ifndef HAVE_UHINV_H
#define HAVE_UHINV_H 1

/* arguments.info */
#define ARGUMENTS_INFO_CPU       0x01
#define ARGUMENTS_INFO_MEM       0x02
#define ARGUMENTS_INFO_OS        0x04
#define ARGUMENTS_INFO_DEVICES   0x08

#define ARGUMENTS_INFO_ALL       0xff

/* arguments.format */
#define ARGUMENTS_FORMAT_TEXT    1
#define ARGUMENTS_FORMAT_PRETTY  2

/* arguments.proc_cpuinfo */
#define ARGUMENTS_BUFSIZE 127

/* Maximum number of filters. This should probably be dynamic, but argp's
 * fondness for for exit()ing makes anything involving malloc() tricky. */
#define FILTER_COUNT 31

/* arguments.filters[].kind */
#define FILTER_KIND_ANY          1
#define FILTER_KIND_BUS          2
#define FILTER_KIND_LOCATION     3
#define FILTER_KIND_NAME         4
#define FILTER_KIND_VENDOR       5
#define FILTER_KIND_CLASS        6

/* arguments.filter_mode */
#define FILTER_MODE_ANY          0
#define FILTER_MODE_ALL          1
#define FILTER_MODE_NONE         2

typedef struct
{
    int kind;
    char *pattern;
} filter_T;

struct arguments
{
    int verbose;
    int info;
    int format;
    char proc_cpuinfo[ARGUMENTS_BUFSIZE];
    char arch[ARGUMENTS_BUFSIZE];
    int filter_count;
    int filter_mode;
    filter_T filters[FILTER_COUNT];
};

extern struct arguments arguments;

#endif

/* vim: set tw=80 sw=4 et : */
