/*
 * Copyright (c) 2004 Ciaran McCreesh <ciaranm at gentoo.org>
 *
 * This file is part of uhinv.
 *
 * uhinv is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * uhinv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * uhinv; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 325, Boston, MA  02111-1257  USA
 */

/**
 * \file   src/util/util.c
 * Various utility functions.
 *
 * A collection of commonly used functions.
 */


#include <string.h>
#include "util.h"

/**
 * Copy up to n characters of string src to dest, making sure that dest ends up
 * with a NULL terminator.
 *
 * \param dest    Destination buffer
 * \param src     Source string
 * \param n       Size of destination
 */
char *strncpynull(dest, src, n)
    char *dest;
    const char *src;
    size_t n;
{
    char *result;
    result = strncpy(dest, src, n - 1);
    dest[n - 1] = '\0';
    return result;
}

/**
 * Overwrite any trailing whitespaces in buf with NULLs.
 *
 * \param buf  Buffer to work with.
 */
    void
kill_training_whitespace(buf)
    char *buf;
{
    char *endbuf;
    endbuf = buf + strlen(buf) - 1;
    while (endbuf >= buf)
    {
        if (*endbuf != ' ' && *endbuf != '\n' && *endbuf != '\t')
            break;
        *endbuf-- = '\0';
    }
}

/* vim: set tw=80 sw=4 et : */
